%XYStage_Usage: PROPERTIES, METHODS, USAGE

%Before use open serial port.
[s,error] = EZStepperOpenSerial('COM3');

%After use close serial port
[error] = EZStepperCloseSerial(s);

%Create XYStage object: 
%Three parameters: PortObj, ControllerNameX, and ControllerNameY are required, other parameters are optional.
%PortObj is the serial port object.
%ControllerName is the controller number on this serial line.
%Values shown are typical defaults. 
%Default or supplied values are loaded into controller at object creation.
% Prior stage 2mm pitch
xy = XYStage('PortObj', s, 'ControllerNameX', 3, 'ControllerNameY', 4, ...
        'LeadUmX', 2000, 'LeadUmY', 2000, ...
        'MotorStepsX', 200, 'MotorStepsY', 200, ...
        'HoldCurrentX', 5, 'HoldCurrentY', 5, ...
        'RunCurrentX', 65, 'RunCurrentY', 65, ...
        'StepDivideX', 256, 'StepDivideY', 256, ...
        'SlewVelocityX', 10000, 'SlewVelocityY', 10000, ...
        'InitVelocityX', 500, 'InitVelocityY', 500, ...
        'RampX', 100, 'RampY', 100, ...
        'LimitPolarity', 1, 'Log', 1);

%Get parameters - values are read from the object data structure. 
%(Ramp is used as an example)
v = get(xy,'RampX'); 
%Set parameters - values are written to the object data structure and loaded into controller.
set(xy,'RampX',v);

%Methods
err = XYRelative(xy,travelx,travely); %Relative move; travel in microns.

err = XYAbsolute(xy,destinationx,destinationy); %Absolute move; destination in microns.

err = XYJog(xy, speedx,speedy); %Jog at given speed in microns/sec. Changes SlewVelocity

err = XYStop(xy); %Stop movement (same as Jog with speed=0)

err = XYHome(xy, homespeedx,homespeedy); %Start moving home at given speed; do not wait for completion.
err = XYHome(xy); %Uses current SlewVelocity. During homing motor moves in the direction of decreasing position.

err = XYHomeComplete(xy, homespeedx,homespeedy); %Home and wait for completion.
err = XYHomeComplete(xy); %Uses current SlewVelocity. During homing motor moves in the direction of decreasing position.
%Original slew velocity is restored after homing.

err = XYHome2Phase(xy, homespeedx,homespeedy); %Two-phase home using XYHomeComplete. First at given speed, then at a fraction of given speed.
err = XYHome2Phase(xy); %Uses current SlewVelocity.

% Home Without Limits - Full travel in negative direction, then back out
err = XYHomeToHardStop(xy, max_travel_to_home_x, move_out_x, max_travel_to_home_y, move_out_y, run_current_x, run_current_y);
%  e.g., errh = XYHomeToHardStop(xy,-80000,1000,-55000,1000, 15,15);

%Home with encoder
err = XYHomeToEncoder(xy, max_travel_to_home_x, max_travel_to_home_y, homespeed_x, homespeed_y, run_current_x, run_current_y, move_out_x, move_out_y, enc_err);
% e.g., err = XYHomeToEncoder(xy, -80000,-55000, 3000,3000, 10,10, 1000,1000, 2);

err = XYWait(xy); %Wait for completion of motion;

err = XYOrigin(xy, originx,originy); %Set position to the given value (in microns), if absent, =0. 
err = XYOrigin(xy);

[posx, posy, err] = XYPos(xy); %Returns current position in microns.

[enposx, enposy, err] = XYEncoderPos(xy); %Returns current encoder position in microns.

[resp, err] = XYExecuteX(xy,cmd); %Execute command on X controller, e.g. 'J1M100J0R'
[resp, err] = XYExecuteY(xy,cmd); %Execute command on Y controller.

err = XYOutX(xy,out); %out: driver1 + 2*driver2 (driver = 0/1)
err = XYOutY(xy,out);

[limits,err] = XYToLimitX(xy,speed); %Move until any limit turns on. Returns the limit that was hit. Changes SlewVelocity
[limits,err] = XYToLimitY(xy,speed); %if already at the limit, returns immediately. sign of speed determines direction of move.
[limits,err] = XYToLimitX(xy); %Uses current SlewVelocity.
[limits,err] = XYToLimitY(xy); %Uses current SlewVelocity.
%limit: 1-limit 1(a), 2-limit 2(b); original slew velocity is restored after homing.

err = XYHomeToHardStop(xy, x_full,x_back,y_full,y_back, x_lowc, y_lowc); %for stages with hard stop
% E.G. err = XYHomeToHardStop(xy,-80000,1000,-55000,1000); or err = XYHomeToHardStop(xy,-80000,1000,-55000,1000,10,10);

log = EZStepperLog(); %Returns log of all executed commands while LogRecord was equal to 1.

EZStepperClearLog; %Clear accumulated log.

% Delete XYStage object
delete(xy);
clear xy;

%GUI FUNCTIONS
XYStage_UI - %Starts XYStage GUI. User must use menus to open COM port and create XYStage object.
%All parameters are changeable by the user. At start GUI figure reads parameter file XYStage.mat from the current 
%directory (if present). Parameter file is (re)written after object creation.
XYStage_UI(<parameter list>); %e.g. any or all of parameters:
XYStage_UI('PortObj', s, 'ControllerNameX', 3, 'ControllerNameY', 4, ...
        'LeadUmX', 1000, 'LeadUmY', 1000, ...
        'MotorStepsX', 200, 'MotorStepsY', 200, ...
        'HoldCurrentX', 5, 'HoldCurrentY', 5, ...
        'RunCurrentX', 65, 'RunCurrentY', 65, ...
        'StepDivideX', 256, 'StepDivideY', 256, ...
        'SlewVelocityX', 10000, 'SlewVelocityY', 10000, ...
        'InitVelocityX', 500, 'InitVelocityY', 500, ...
        'RampX', 100, 'RampY', 100, ...
        'LimitPolarity', 1, 'Log', 1);
%Parameters that are in the list can not be changed by the user from the GUI. 
%Parameters that are not in the list can be changed by the user from the GUI.
%Parameters from the command line override parameters read from the file.
%If Serial Port Object was created before invoking the GUI and passed to
%it, the port does not need to (and can not) be opened. However, the user still
%must create the XYStage object in the menu: Initialize/Create XYStage Object.

% Relevant functions:

%               EZStepperOpenSerial     EZStepperCloseSerial 
%               EZStepperLog            EZStepperClearLog  
%               XYStage_Test*           XYStage_UI (.m and .fig)
%               XYStage_Usage           XYStage
